@@ -1,6 +1,6 @@
 import pytest
 
-from fsspec.implementations.local import LocalFileSystem
+from fsspec.implementations.local import LocalFileSystem, make_path_posix
 from fsspec.tests.abstract import AbstractFixtures
 
 
@@ -12,3 +12,7 @@ class LocalFixtures(AbstractFixtures):
     @pytest.fixture
     def fs_path(self, tmpdir):
         return str(tmpdir)
+
+    @pytest.fixture
+    def fs_sanitize_path(self):
+        return make_path_posix
